@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -8,11 +8,22 @@
 
 #include "pimcommon_export.h"
 
+#include "config-pimcommon.h"
 #include <PimCommon/SpellCheckLineEdit>
+#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
+namespace TextAutoCorrectionCore
+{
+class AutoCorrection;
+}
+#else
+namespace TextAutoCorrection
+{
+class AutoCorrection;
+}
+#endif
 
 namespace PimCommon
 {
-class AutoCorrection;
 class LineEditWithAutoCorrectionPrivate;
 /**
  * @brief The LineEditWithAutoCorrection class
@@ -25,9 +36,13 @@ public:
     explicit LineEditWithAutoCorrection(QWidget *parent, const QString &configFile);
     ~LineEditWithAutoCorrection() override;
 
-    Q_REQUIRED_RESULT PimCommon::AutoCorrection *autocorrection() const;
-
-    void setAutocorrection(PimCommon::AutoCorrection *autocorrect);
+#if HAVE_TEXT_AUTOCORRECTION_WIDGETS
+    Q_REQUIRED_RESULT TextAutoCorrectionCore::AutoCorrection *autocorrection() const;
+    void setAutocorrection(TextAutoCorrectionCore::AutoCorrection *autocorrect);
+#else
+    Q_REQUIRED_RESULT TextAutoCorrection::AutoCorrection *autocorrection() const;
+    void setAutocorrection(TextAutoCorrection::AutoCorrection *autocorrect);
+#endif
     void setAutocorrectionLanguage(const QString &language);
 
 protected:
@@ -37,4 +52,3 @@ private:
     std::unique_ptr<LineEditWithAutoCorrectionPrivate> const d;
 };
 }
-
