@@ -1,28 +1,17 @@
 /*
-  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
-#ifndef AbstractGENERICPLUGININTERFACE_H
-#define AbstractGENERICPLUGININTERFACE_H
-#include <QObject>
+#pragma once
 #include "pimcommon_export.h"
+#include <QObject>
+#include <memory>
 class QAction;
 class KActionCollection;
-namespace PimCommon {
+namespace PimCommon
+{
 class AbstractGenericPlugin;
 class GenericPlugin;
 /**
@@ -40,16 +29,16 @@ public:
         PopupMenu = 4,
         ToolBar = 5,
         Message = 6,
-        Folder = 7
+        Folder = 7,
     };
-    ActionType()
-    {
-    }
+    ActionType() = default;
 
     ActionType(QAction *action, Type type);
     Q_REQUIRED_RESULT QAction *action() const;
     Q_REQUIRED_RESULT Type type() const;
 
+    Q_REQUIRED_RESULT bool operator==(const ActionType &other) const;
+
 private:
     QAction *mAction = nullptr;
     Type mType = Tools;
@@ -61,7 +50,7 @@ class PIMCOMMON_EXPORT AbstractGenericPluginInterface : public QObject
     Q_OBJECT
 public:
     explicit AbstractGenericPluginInterface(QObject *parent = nullptr);
-    ~AbstractGenericPluginInterface();
+    ~AbstractGenericPluginInterface() override;
 
     void setParentWidget(QWidget *parent);
     Q_REQUIRED_RESULT QWidget *parentWidget() const;
@@ -79,7 +68,6 @@ Q_SIGNALS:
     void message(const QString &str);
 
 private:
-    AbstractGenericPluginInterfacePrivate *const d;
+    std::unique_ptr<AbstractGenericPluginInterfacePrivate> const d;
 };
 }
-#endif // AbstractGENERICPLUGININTERFACE_H
