@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -38,7 +38,7 @@ QString pluginVersion()
 class PimCommon::GenericPluginManagerPrivate
 {
 public:
-    GenericPluginManagerPrivate(GenericPluginManager *qq)
+    explicit GenericPluginManagerPrivate(GenericPluginManager *qq)
         : q(qq)
     {
     }
