@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -36,12 +36,11 @@ public:
     ~TemplateManager() override;
 
 private:
-    void slotDirectoryChanged();
-    void loadTemplates(bool init = false);
-    void initTemplatesDirectories(const QString &templatesRelativePath);
-    TemplateInfo loadTemplate(const QString &themePath, const QString &defaultDesktopFileName);
+    PIMCOMMON_NO_EXPORT void slotDirectoryChanged();
+    PIMCOMMON_NO_EXPORT void loadTemplates(bool init = false);
+    PIMCOMMON_NO_EXPORT void initTemplatesDirectories(const QString &templatesRelativePath);
+    Q_REQUIRED_RESULT PIMCOMMON_NO_EXPORT TemplateInfo loadTemplate(const QString &themePath, const QString &defaultDesktopFileName);
 
     std::unique_ptr<TemplateManagerPrivate> const d;
 };
 }
-
