@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -29,8 +29,8 @@ public:
     void setShowDefaultText(bool b);
 
 private:
-    void generalPaletteChanged();
-    void generalFontChanged();
+    PIMCOMMON_NO_EXPORT void generalPaletteChanged();
+    PIMCOMMON_NO_EXPORT void generalFontChanged();
 
 protected:
     void paintEvent(QPaintEvent *event) override;
@@ -44,4 +44,3 @@ private:
     QString mDefaultText;
 };
 }
-
