@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2017-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,9 +23,7 @@ LineEditWithCompleterNg::LineEditWithCompleterNg(QWidget *parent)
     setCompleter(completer);
 }
 
-LineEditWithCompleterNg::~LineEditWithCompleterNg()
-{
-}
+LineEditWithCompleterNg::~LineEditWithCompleterNg() = default;
 
 void LineEditWithCompleterNg::addCompletionItem(const QString &str)
 {
