@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2011-2021 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2011-2023 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
  */
@@ -36,14 +36,13 @@ public:
     Q_REQUIRED_RESULT QUrl newName() const;
 
 private:
-    void slotOverwritePressed();
-    void slotIgnorePressed();
-    void slotRenamePressed();
-    void slotApplyAllPressed();
-    void slotSuggestNewNamePressed();
+    PIMCOMMON_NO_EXPORT void slotOverwritePressed();
+    PIMCOMMON_NO_EXPORT void slotIgnorePressed();
+    PIMCOMMON_NO_EXPORT void slotRenamePressed();
+    PIMCOMMON_NO_EXPORT void slotApplyAllPressed();
+    PIMCOMMON_NO_EXPORT void slotSuggestNewNamePressed();
     //@cond PRIVATE
     class RenameFileDialogPrivate;
     std::unique_ptr<RenameFileDialogPrivate> const d;
 };
 }
-
