@@ -1,47 +1,33 @@
 /*
-  Copyright (c) 2016-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2016-2023 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "aclmodifyjob.h"
-#include "imapresourcesettings.h"
-#include "util/pimutil.h"
 #include "aclutils_p.h"
+#include "imapresourcesettings.h"
 #include "pimcommonakonadi_debug.h"
-#include <AkonadiCore/ServerManager>
+#include "util/pimutil.h"
+#include <Akonadi/ServerManager>
 #include <KEmailAddress>
 
 #include "imapaclattribute.h"
 
-#include <KMessageBox>
+#include <Akonadi/CollectionFetchJob>
+#include <Akonadi/CollectionFetchScope>
+#include <Akonadi/CollectionModifyJob>
+#include <Akonadi/ContactGroupExpandJob>
+#include <Akonadi/ContactGroupSearchJob>
+#include <KContacts/Addressee>
 #include <KLocalizedString>
+#include <KMessageBox>
 #include <QDBusInterface>
 #include <QDBusReply>
-#include <ContactGroupSearchJob>
-#include <ContactGroupExpandJob>
-#include <AkonadiCore/CollectionModifyJob>
-#include <AkonadiCore/CollectionFetchJob>
-#include <AkonadiCore/CollectionFetchScope>
-#include <KContacts/Addressee>
-#include <collectionfetchjob.h>
 
 using namespace PimCommon;
-//#define SEARCHCONTACT_AKONADI 1
+// #define SEARCHCONTACT_AKONADI 1
 
 AclModifyJob::AclModifyJob(QObject *parent)
     : QObject(parent)
@@ -50,15 +36,13 @@ AclModifyJob::AclModifyJob(QObject *parent)
     connect(this, &AclModifyJob::searchNextContact, this, &AclModifyJob::searchContact);
 }
 
-AclModifyJob::~AclModifyJob()
-{
-}
+AclModifyJob::~AclModifyJob() = default;
 
 void AclModifyJob::searchContact()
 {
     const QMap<QByteArray, KIMAP::Acl::Rights>::const_iterator itEnd = mCurrentRight.cend();
     if (mIt != itEnd) {
-        Akonadi::ContactGroupSearchJob *searchJob = new Akonadi::ContactGroupSearchJob(this);
+        auto searchJob = new Akonadi::ContactGroupSearchJob(this);
         searchJob->setQuery(Akonadi::ContactGroupSearchJob::Name, QString::fromLatin1(mIt.key()));
         searchJob->setLimit(1);
         connect(searchJob, &Akonadi::ContactGroupSearchJob::result, this, &AclModifyJob::slotGroupSearchResult);
@@ -69,24 +53,22 @@ void AclModifyJob::searchContact()
 
 void AclModifyJob::slotGroupSearchResult(KJob *job)
 {
-    Akonadi::ContactGroupSearchJob *searchJob = qobject_cast<Akonadi::ContactGroupSearchJob *>(job);
-    if (!searchJob->contactGroups().isEmpty()) {   // it has been a distribution list
-        Akonadi::ContactGroupExpandJob *expandJob
-            = new Akonadi::ContactGroupExpandJob(searchJob->contactGroups().at(0), this);
+    auto searchJob = qobject_cast<Akonadi::ContactGroupSearchJob *>(job);
+    if (!searchJob->contactGroups().isEmpty()) { // it has been a distribution list
+        auto expandJob = new Akonadi::ContactGroupExpandJob(searchJob->contactGroups().at(0), this);
         if (expandJob->exec()) {
             const KContacts::Addressee::List lstContacts = expandJob->contacts();
             for (const KContacts::Addressee &contact : lstContacts) {
-                const QByteArray rawEmail
-                    = KEmailAddress::extractEmailAddress(contact.preferredEmail().toUtf8());
+                const QByteArray rawEmail = KEmailAddress::extractEmailAddress(contact.preferredEmail().toUtf8());
                 if (!rawEmail.isEmpty()) {
-                    mNewRight[ rawEmail ] = mIt.value();
+                    mNewRight[rawEmail] = mIt.value();
                 }
             }
         }
     } else { // it has been a normal contact
         const QByteArray rawEmail = KEmailAddress::extractEmailAddress(mIt.key());
         if (!rawEmail.isEmpty()) {
-            mNewRight[ rawEmail ] = mIt.value();
+            mNewRight[rawEmail] = mIt.value();
         }
     }
     ++mIt;
@@ -122,16 +104,15 @@ void AclModifyJob::slotModifyAcl()
     if (mRecursive) {
         auto job = new Akonadi::CollectionFetchJob(mTopLevelCollection, Akonadi::CollectionFetchJob::Recursive, this);
         job->fetchScope().setAncestorRetrieval(Akonadi::CollectionFetchScope::All);
-        connect(job, &Akonadi::CollectionFetchJob::finished,
-                this, [this](KJob *job) {
-                    if (job->error()) {
-                        qCWarning(PIMCOMMONAKONADI_LOG) << job->errorString();
-                        slotFetchCollectionFailed();
-                    } else {
-                        auto fetch = static_cast<Akonadi::CollectionFetchJob*>(job);
-                        slotFetchCollectionFinished(fetch->collections());
-                    }
-                });
+        connect(job, &Akonadi::CollectionFetchJob::finished, this, [this](KJob *job) {
+            if (job->error()) {
+                qCWarning(PIMCOMMONAKONADI_LOG) << job->errorString();
+                slotFetchCollectionFailed();
+            } else {
+                auto fetch = static_cast<Akonadi::CollectionFetchJob *>(job);
+                slotFetchCollectionFinished(fetch->collections());
+            }
+        });
     } else {
         changeAcl(mTopLevelCollection);
     }
@@ -146,8 +127,7 @@ bool AclModifyJob::canAdministrate(const PimCommon::ImapAclAttribute *attribute,
 
     QString resource = collection.resource();
     if (resource.contains(QLatin1String("akonadi_kolabproxy_resource"))) {
-        const QString basename = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent,
-                                                                          QStringLiteral("akonadi_kolabproxy_resource"));
+        const QString basename = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Agent, QStringLiteral("akonadi_kolabproxy_resource"));
         QDBusInterface interface(basename, QStringLiteral("/KolabProxy"));
         if (interface.isValid()) {
             QDBusReply<QString> reply = interface.call(QStringLiteral("imapResourceForCollection"), collection.remoteId().toLongLong());
@@ -156,8 +136,7 @@ bool AclModifyJob::canAdministrate(const PimCommon::ImapAclAttribute *attribute,
             }
         }
     }
-    OrgKdeAkonadiImapSettingsInterface *imapSettingsInterface
-        = PimCommon::Util::createImapSettingsInterface(resource);
+    OrgKdeAkonadiImapSettingsInterface *imapSettingsInterface = PimCommon::Util::createImapSettingsInterface(resource);
 
     QString loginName;
     QString serverName;
@@ -183,7 +162,7 @@ bool AclModifyJob::canAdministrate(const PimCommon::ImapAclAttribute *attribute,
             imapUserName = guessedUserName;
         }
     }
-    return rights[ imapUserName.toUtf8() ] & KIMAP::Acl::Admin;
+    return rights[imapUserName.toUtf8()] & KIMAP::Acl::Admin;
 }
 
 void AclModifyJob::setCurrentRight(const QMap<QByteArray, KIMAP::Acl::Rights> &currentRight)
@@ -195,10 +174,10 @@ void AclModifyJob::changeAcl(const Akonadi::Collection &collection)
 {
     if (collection.hasAttribute<PimCommon::ImapAclAttribute>()) {
         Akonadi::Collection mutableCollection = collection;
-        PimCommon::ImapAclAttribute *attribute = mutableCollection.attribute<PimCommon::ImapAclAttribute>();
+        auto attribute = mutableCollection.attribute<PimCommon::ImapAclAttribute>();
         if (canAdministrate(attribute, mutableCollection)) {
             attribute->setRights(mNewRight);
-            Akonadi::CollectionModifyJob *modifyJob = new Akonadi::CollectionModifyJob(mutableCollection);
+            auto modifyJob = new Akonadi::CollectionModifyJob(mutableCollection);
             connect(modifyJob, &KJob::result, this, &AclModifyJob::slotModifyDone);
         }
     } else {
@@ -229,7 +208,7 @@ void AclModifyJob::slotFetchCollectionFinished(const Akonadi::Collection::List &
     QStringList folderNames;
     for (const Akonadi::Collection &col : collectionList) {
         if (col.hasAttribute<PimCommon::ImapAclAttribute>()) {
-            const PimCommon::ImapAclAttribute *attribute = col.attribute<PimCommon::ImapAclAttribute>();
+            const auto attribute = col.attribute<PimCommon::ImapAclAttribute>();
             if (canAdministrate(attribute, col)) {
                 QString fullName;
                 bool parentFound;
@@ -261,7 +240,8 @@ void AclModifyJob::slotFetchCollectionFinished(const Akonadi::Collection::List &
     if (KMessageBox::warningContinueCancelList(nullptr,
                                                i18n("Do you really want to apply the folder's permissions to these subfolders?"),
                                                folderNames,
-                                               i18n("Apply Permissions")) != KMessageBox::Continue) {
+                                               i18n("Apply Permissions"))
+        != KMessageBox::Continue) {
         deleteLater();
         qCDebug(PIMCOMMONAKONADI_LOG) << "AclModifyJob: User canceled .";
         return;
