@@ -1,12 +1,12 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
 #include "completionconfiguredialogtest.h"
-#include "../completionconfiguredialog/completionconfiguredialog.h"
+#include "addressline/completionconfiguredialog/completionconfiguredialog.h"
 #include <QDialogButtonBox>
 #include <QStandardPaths>
 #include <QTabWidget>
@@ -17,9 +17,7 @@ CompletionConfigureDialogTest::CompletionConfigureDialogTest(QObject *parent)
 {
 }
 
-CompletionConfigureDialogTest::~CompletionConfigureDialogTest()
-{
-}
+CompletionConfigureDialogTest::~CompletionConfigureDialogTest() = default;
 
 void CompletionConfigureDialogTest::initTestCase()
 {
@@ -32,6 +30,7 @@ void CompletionConfigureDialogTest::shouldHaveDefaultValue()
 
     auto buttonBox = dlg.findChild<QDialogButtonBox *>(QStringLiteral("buttonbox"));
     QVERIFY(buttonBox);
+    QCOMPARE(buttonBox->standardButtons(), QDialogButtonBox::StandardButtons{QDialogButtonBox::Ok | QDialogButtonBox::Apply | QDialogButtonBox::Cancel});
 
     auto tabWidget = dlg.findChild<QTabWidget *>(QStringLiteral("tabwidget"));
     QVERIFY(tabWidget);
