@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -14,14 +14,14 @@ BlackListBalooEmailListTest::BlackListBalooEmailListTest(QObject *parent)
 {
 }
 
-BlackListBalooEmailListTest::~BlackListBalooEmailListTest()
-{
-}
+BlackListBalooEmailListTest::~BlackListBalooEmailListTest() = default;
 
 void BlackListBalooEmailListTest::shouldHaveDefaultValue()
 {
     PimCommon::BlackListBalooEmailList blackList;
     QVERIFY(blackList.count() == 0);
+    QVERIFY(blackList.isSortingEnabled());
+    QCOMPARE(blackList.selectionMode(), QAbstractItemView::ExtendedSelection);
 }
 
 void BlackListBalooEmailListTest::shouldFillListEmail()
@@ -83,14 +83,14 @@ void BlackListBalooEmailListTest::shouldNotAddDuplicateEmails()
 void BlackListBalooEmailListTest::shouldExcludeDomain()
 {
     PimCommon::BlackListBalooEmailList blackList;
-    blackList.setExcludeDomain(QStringList() << QStringLiteral("kde.org") << QStringLiteral("toto.fr"));
+    blackList.setExcludeDomains(QStringList() << QStringLiteral("kde.org") << QStringLiteral("toto.fr"));
     QStringList emails = QStringList() << QStringLiteral("foo@kde.org") << QStringLiteral("bli@fr.fr") << QStringLiteral("bli@toto.fr");
     blackList.setEmailBlackList(emails);
     QCOMPARE(blackList.setEmailFound(emails), 1);
 
     QCOMPARE(blackList.count(), 1);
 
-    blackList.setExcludeDomain(QStringList() << QStringLiteral("kde.org") << QStringLiteral("toto.fr"));
+    blackList.setExcludeDomains(QStringList() << QStringLiteral("kde.org") << QStringLiteral("toto.fr"));
     emails = QStringList() << QStringLiteral("<foo@kde.org>") << QStringLiteral("bli@fr.fr") << QStringLiteral("bli@toto.fr");
     blackList.setEmailBlackList(emails);
     QCOMPARE(blackList.setEmailFound(emails), 1);
