@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -30,6 +30,9 @@ void BlackListBalooEmailWarningTest::shouldHaveDefaultValue()
 
     auto search = warning.findChild<QAction *>(QStringLiteral("search"));
     QVERIFY(search);
+
+    auto cancelAction = warning.findChild<QAction *>(QStringLiteral("cancel"));
+    QVERIFY(cancelAction);
 }
 
 void BlackListBalooEmailWarningTest::shouldEmitSaveChanges()
