@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -40,19 +40,21 @@ private:
     void slotSaveChanges();
     void slotShowAllBlacklistedEmail();
     void hideMoreResultAndChangeLimit();
+    void slotCustomContextMenuRequested(const QPoint &pos);
     QStringList mOriginalExcludeDomain;
-    QLabel *mNumberOfEmailsFound = nullptr;
-    QLineEdit *mSearchLineEdit = nullptr;
-    QLineEdit *mExcludeDomainLineEdit = nullptr;
-    BlackListBalooEmailList *mEmailList = nullptr;
-    QPushButton *mSearchButton = nullptr;
-    QPushButton *mSelectButton = nullptr;
-    QPushButton *mUnselectButton = nullptr;
-    QPushButton *mShowAllBlackListedEmails = nullptr;
-    QLabel *mMoreResult = nullptr;
+    QStringList mOriginalExcludeEmailRegexp;
+    QLabel *const mNumberOfEmailsFound;
+    QLineEdit *const mSearchLineEdit;
+    QLineEdit *const mExcludeDomainLineEdit;
+    BlackListBalooEmailList *const mEmailList;
+    QPushButton *const mSearchButton;
+    QPushButton *const mSelectButton;
+    QPushButton *const mUnselectButton;
+    QPushButton *const mShowAllBlackListedEmails;
+    QLabel *const mMoreResult;
     KListWidgetSearchLine *mSearchInResultLineEdit = nullptr;
-    BlackListBalooEmailWarning *mBlackListWarning = nullptr;
+    BlackListBalooEmailWarning *const mBlackListWarning;
+    QLineEdit *const mExcludeEmailFromRegularExpressionLineEdit;
     int mLimit = 500;
 };
 }
-
