@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -18,6 +18,7 @@ BlackListBalooEmailList::BlackListBalooEmailList(QWidget *parent)
 {
     setSelectionMode(QAbstractItemView::ExtendedSelection);
     setSortingEnabled(true);
+    setContextMenuPolicy(Qt::CustomContextMenu);
 }
 
 BlackListBalooEmailList::~BlackListBalooEmailList() = default;
@@ -49,9 +50,9 @@ QHash<QString, bool> BlackListBalooEmailList::blackListItemChanged() const
     return result;
 }
 
-void BlackListBalooEmailList::setExcludeDomain(const QStringList &domain)
+void BlackListBalooEmailList::setExcludeDomains(const QStringList &domain)
 {
-    mExcludeDomain = domain;
+    mExcludeDomains = domain;
 }
 
 int BlackListBalooEmailList::setEmailFound(const QStringList &list)
@@ -62,20 +63,31 @@ int BlackListBalooEmailList::setEmailFound(const QStringList &list)
     QStringList emailsLower;
     QStringList onlyEmails;
     for (const QString &mail : list) {
-        bool excludeDomain = false;
+        bool excludeEmail = false;
         QString email;
         QString name;
         KEmailAddress::extractEmailAddressAndName(mail, email, name);
 
         const QString mailToLower = mail.toLower();
         const QString emailToLower = email.toLower();
-        for (const QString &domain : std::as_const(mExcludeDomain)) {
+        for (const QString &domain : std::as_const(mExcludeDomains)) {
             if (email.endsWith(domain)) {
-                excludeDomain = true;
+                excludeEmail = true;
                 break;
             }
         }
-        if (excludeDomain) {
+        if (!excludeEmail) {
+            // Make it static
+            for (const QString &excludeEmailRegularExpression : std::as_const(mExcludeEmailsRegularExpressions)) {
+                if (!excludeEmailRegularExpression.isEmpty()) {
+                    if (email.contains(QRegularExpression(excludeEmailRegularExpression))) {
+                        excludeEmail = true;
+                        continue;
+                    }
+                }
+            }
+        }
+        if (excludeEmail) {
             continue;
         }
         if (!emailsAdded.contains(mail) && !emailsLower.contains(mailToLower) && !onlyEmails.contains(emailToLower)) {
@@ -103,6 +115,11 @@ void BlackListBalooEmailList::generalPaletteChanged()
     mTextColor = color;
 }
 
+void BlackListBalooEmailList::setExcludeEmailsRegularExpressions(const QStringList &newExcludeEmailsRegularExpressions)
+{
+    mExcludeEmailsRegularExpressions = newExcludeEmailsRegularExpressions;
+}
+
 void BlackListBalooEmailList::paintEvent(QPaintEvent *event)
 {
     if (mFirstResult && (!model() || model()->rowCount() == 0)) {
