@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -7,7 +7,7 @@
 
 #include "blacklistbalooemailsearchjob.h"
 
-#include <AkonadiSearch/PIM/contactcompleter.h>
+#include <PIM/contactcompleter.h>
 using namespace PimCommon;
 
 BlackListBalooEmailSearchJob::BlackListBalooEmailSearchJob(QObject *parent)
@@ -15,9 +15,7 @@ BlackListBalooEmailSearchJob::BlackListBalooEmailSearchJob(QObject *parent)
 {
 }
 
-BlackListBalooEmailSearchJob::~BlackListBalooEmailSearchJob()
-{
-}
+BlackListBalooEmailSearchJob::~BlackListBalooEmailSearchJob() = default;
 
 bool BlackListBalooEmailSearchJob::start()
 {
