@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -10,9 +10,12 @@
 #include <KLDAP/LdapClientSearch>
 #include <KLocalizedString>
 #include <KSharedConfig>
+#include <KWindowConfig>
 #include <QDialogButtonBox>
+#include <QPushButton>
 #include <QTabWidget>
 #include <QVBoxLayout>
+#include <QWindow>
 
 #include <addressline/completionorder/completionorderwidget.h>
 #include <config-akonadi-search.h>
@@ -22,13 +25,14 @@
 #include <addressline/recentaddress/recentaddresswidget.h>
 
 using namespace PimCommon;
-
+namespace
+{
+static const char myCompletionConfigureDialogGroupName[] = "CompletionConfigureDialog";
+}
 class PimCommon::CompletionConfigureDialogPrivate
 {
 public:
-    CompletionConfigureDialogPrivate()
-    {
-    }
+    CompletionConfigureDialogPrivate() = default;
 
     QTabWidget *mTabWidget = nullptr;
     PimCommon::CompletionOrderWidget *mCompletionOrderWidget = nullptr;
@@ -63,9 +67,10 @@ CompletionConfigureDialog::CompletionConfigureDialog(QWidget *parent)
     d->mTabWidget->addTab(d->mBlackListBalooWidget, i18n("Blacklist Email Address"));
 #endif
 
-    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel, this);
+    auto buttonBox = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Apply | QDialogButtonBox::Cancel, this);
     buttonBox->setObjectName(QStringLiteral("buttonbox"));
-    connect(buttonBox, &QDialogButtonBox::accepted, this, &CompletionConfigureDialog::slotSave);
+    connect(buttonBox, &QDialogButtonBox::accepted, this, &CompletionConfigureDialog::slotSaveAndClose);
+    connect(buttonBox->button(QDialogButtonBox::Apply), &QPushButton::clicked, this, &CompletionConfigureDialog::slotSave);
     connect(buttonBox, &QDialogButtonBox::rejected, this, &QDialog::reject);
     mainLayout->addWidget(buttonBox);
     readConfig();
@@ -78,18 +83,17 @@ CompletionConfigureDialog::~CompletionConfigureDialog()
 
 void CompletionConfigureDialog::readConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "CompletionConfigureDialog");
-    const QSize size = group.readEntry("Size", QSize(600, 400));
-    if (size.isValid()) {
-        resize(size);
-    }
+    create(); // ensure a window is created
+    windowHandle()->resize(QSize(600, 400));
+    KConfigGroup group(KSharedConfig::openStateConfig(), myCompletionConfigureDialogGroupName);
+    KWindowConfig::restoreWindowSize(windowHandle(), group);
+    resize(windowHandle()->size()); // workaround for QTBUG-40584
 }
 
 void CompletionConfigureDialog::writeConfig()
 {
-    KConfigGroup group(KSharedConfig::openStateConfig(), "CompletionConfigureDialog");
-    group.writeEntry("Size", size());
-    group.sync();
+    KConfigGroup group(KSharedConfig::openStateConfig(), myCompletionConfigureDialogGroupName);
+    KWindowConfig::saveWindowSize(windowHandle(), group);
 }
 
 void CompletionConfigureDialog::setRecentAddresses(const QStringList &lst)
@@ -120,13 +124,18 @@ void CompletionConfigureDialog::storeAddresses(KConfig *config)
     d->mRecentaddressWidget->storeAddresses(config);
 }
 
+void CompletionConfigureDialog::slotSaveAndClose()
+{
+    slotSave();
+    accept();
+}
+
 void CompletionConfigureDialog::slotSave()
 {
 #if !DISABLE_AKONADI_SEARCH
     d->mBlackListBalooWidget->save();
 #endif
     d->mCompletionOrderWidget->save();
-    accept();
 }
 
 void CompletionConfigureDialog::setEmailBlackList(const QStringList &lst)
