@@ -1,5 +1,5 @@
 /*
-   SPDX-FileCopyrightText: 2017-2022 Laurent Montel <montel@kde.org>
+   SPDX-FileCopyrightText: 2017-2023 Laurent Montel <montel@kde.org>
 
    SPDX-License-Identifier: LGPL-2.0-or-later
 */
@@ -36,7 +36,7 @@ QString pluginVersion()
 class PimCommon::AddressessLineEditPluginManagerPrivate
 {
 public:
-    AddressessLineEditPluginManagerPrivate(AddressessLineEditPluginManager *qq)
+    explicit AddressessLineEditPluginManagerPrivate(AddressessLineEditPluginManager *qq)
         : q(qq)
     {
         initializePlugins();
