@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2015-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2015-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -37,9 +37,10 @@ protected:
     bool eventFilter(QObject *o, QEvent *e) override;
 
 private:
-    void slotAddItem();
-    void slotRemoveItem();
-    void slotUpdateAddButton(const QString &str);
+    PIMCOMMONAKONADI_NO_EXPORT void slotAddItem();
+    PIMCOMMONAKONADI_NO_EXPORT void slotRemoveItem();
+    PIMCOMMONAKONADI_NO_EXPORT void slotUpdateAddButton(const QString &str);
+    PIMCOMMONAKONADI_NO_EXPORT void slotCustomContextMenuRequested(const QPoint &pos);
     QLineEdit *const mLineEdit;
     QToolButton *const mNewButton;
     QToolButton *const mRemoveButton;
