@@ -1,30 +1,17 @@
 /*
-  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
-  This library is free software; you can redistribute it and/or modify it
-  under the terms of the GNU Library General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or (at your
-  option) any later version.
-
-  This library is distributed in the hope that it will be useful, but WITHOUT
-  ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
-  FITNESS FOR A PARTICULAR PURPOSE.  See the GNU Library General Public
-  License for more details.
-
-  You should have received a copy of the GNU Library General Public License
-  along with this library; see the file COPYING.LIB.  If not, write to the
-  Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA
-  02110-1301, USA.
+  SPDX-License-Identifier: LGPL-2.0-or-later
 
 */
 
-#ifndef COLLECTIONTYPEUTIL_H
-#define COLLECTIONTYPEUTIL_H
+#pragma once
 #include "pimcommonakonadi_export.h"
 #include <QByteArray>
 #include <QString>
 
-namespace PimCommon {
+namespace PimCommon
+{
 /**
  * @brief The CollectionTypeUtil class
  * @author Laurent Montel <montel@kde.org>
@@ -55,7 +42,7 @@ public:
     enum IncidencesFor {
         IncForNobody,
         IncForAdmins,
-        IncForReaders
+        IncForReaders,
     };
 
     Q_REQUIRED_RESULT CollectionTypeUtil::IncidencesFor incidencesForFromString(const QString &string);
@@ -68,4 +55,3 @@ public:
     Q_REQUIRED_RESULT QString iconNameFromContentsType(CollectionTypeUtil::FolderContentsType type);
 };
 }
-#endif // COLLECTIONTYPEUTIL_H
