@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2021 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -23,9 +23,7 @@ using namespace PimCommon;
 class PimCommon::CheckedCollectionWidgetPrivate
 {
 public:
-    CheckedCollectionWidgetPrivate()
-    {
-    }
+    CheckedCollectionWidgetPrivate() = default;
 
     QTreeView *mFolderView = nullptr;
     QItemSelectionModel *mSelectionModel = nullptr;
