@@ -1,5 +1,5 @@
 /*
-  SPDX-FileCopyrightText: 2013-2022 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2013-2023 Laurent Montel <montel@kde.org>
 
   SPDX-License-Identifier: GPL-2.0-or-later
 */
@@ -46,7 +46,7 @@ Q_SIGNALS:
     void collectionRemoved(const Akonadi::Collection &);
 
 private:
-    void slotSetCollectionFilter(const QString &filter);
+    PIMCOMMONAKONADI_NO_EXPORT void slotSetCollectionFilter(const QString &filter);
     std::unique_ptr<CheckedCollectionWidgetPrivate> const d;
 };
 }
