@@ -1,26 +1,14 @@
 /*
-  Copyright (c) 2014-2020 Laurent Montel <montel@kde.org>
+  SPDX-FileCopyrightText: 2014-2023 Laurent Montel <montel@kde.org>
 
-  This program is free software; you can redistribute it and/or modify it
-  under the terms of the GNU General Public License as published by
-  the Free Software Foundation; either version 2 of the License, or
-  (at your option) any later version.
-
-  This program is distributed in the hope that it will be useful, but
-  WITHOUT ANY WARRANTY; without even the implied warranty of
-  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-  General Public License for more details.
-
-  You should have received a copy of the GNU General Public License along
-  with this program; if not, write to the Free Software Foundation, Inc.,
-  51 Franklin Street, Fifth Floor, Boston, MA  02110-1301  USA
+  SPDX-License-Identifier: GPL-2.0-or-later
 */
 
 #include "manageserversidesubscriptionjob.h"
-#include "util/mailutil.h"
 #include "pimcommonakonadi_debug.h"
+#include "util/mailutil.h"
 
-#include <AkonadiCore/ServerManager>
+#include <Akonadi/ServerManager>
 
 #include <KLocalizedString>
 #include <KMessageBox>
@@ -35,9 +23,7 @@ using namespace PimCommon;
 class PimCommon::ManageServerSideSubscriptionJobPrivate
 {
 public:
-    ManageServerSideSubscriptionJobPrivate()
-    {
-    }
+    ManageServerSideSubscriptionJobPrivate() = default;
 
     Akonadi::Collection mCurrentCollection;
     QWidget *mParentWidget = nullptr;
@@ -49,10 +35,7 @@ ManageServerSideSubscriptionJob::ManageServerSideSubscriptionJob(QObject *parent
 {
 }
 
-ManageServerSideSubscriptionJob::~ManageServerSideSubscriptionJob()
-{
-    delete d;
-}
+ManageServerSideSubscriptionJob::~ManageServerSideSubscriptionJob() = default;
 
 void ManageServerSideSubscriptionJob::start()
 {
@@ -63,19 +46,15 @@ void ManageServerSideSubscriptionJob::start()
     }
     bool isImapOnline = false;
     if (PimCommon::MailUtil::isImapFolder(d->mCurrentCollection, isImapOnline)) {
-        const QString service
-            = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource,
-                                                       d->mCurrentCollection.resource());
-        QDBusInterface iface(service,
-                             QStringLiteral("/"), QStringLiteral("org.kde.Akonadi.ImapResourceBase"),
-                             QDBusConnection::sessionBus(), this);
+        const QString service = Akonadi::ServerManager::agentServiceName(Akonadi::ServerManager::Resource, d->mCurrentCollection.resource());
+        QDBusInterface iface(service, QStringLiteral("/"), QStringLiteral("org.kde.Akonadi.ImapResourceBase"), QDBusConnection::sessionBus(), this);
         if (!iface.isValid()) {
             qCDebug(PIMCOMMONAKONADI_LOG) << "Cannot create imap dbus interface for service " << service;
             deleteLater();
             return;
         }
         QDBusPendingCall call = iface.asyncCall(QStringLiteral("configureSubscription"), (qlonglong)d->mParentWidget->winId());
-        QDBusPendingCallWatcher *watcher = new QDBusPendingCallWatcher(call, this);
+        auto watcher = new QDBusPendingCallWatcher(call, this);
         connect(watcher, &QDBusPendingCallWatcher::finished, this, &ManageServerSideSubscriptionJob::slotConfigureSubscriptionFinished);
     }
 }
@@ -85,7 +64,9 @@ void ManageServerSideSubscriptionJob::slotConfigureSubscriptionFinished(QDBusPen
     QDBusPendingReply<int> reply = *watcher;
     if (reply.isValid()) {
         if (reply == -2) {
-            KMessageBox::error(d->mParentWidget, i18n("IMAP server not configured yet. Please configure the server in the IMAP account before setting up server-side subscription."));
+            KMessageBox::error(
+                d->mParentWidget,
+                i18n("IMAP server not configured yet. Please configure the server in the IMAP account before setting up server-side subscription."));
         } else if (reply == -1) {
             KMessageBox::error(d->mParentWidget, i18n("Log in failed, please configure the IMAP account before setting up server-side subscription."));
         }
@@ -93,7 +74,6 @@ void ManageServerSideSubscriptionJob::slotConfigureSubscriptionFinished(QDBusPen
         qCDebug(PIMCOMMONAKONADI_LOG) << "ManageServerSideSubscriptionJob return an invalid reply";
     }
     watcher->deleteLater();
-    watcher = nullptr;
     deleteLater();
 }
 
